import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-BETZMhtt.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-C3bBZEB2.js";import"./router-gFtZE6ii.js";import"./ts.worker-CPZkBJf0.js";import"./fetch-D81uCHNs.js";import"./record-DQ7WGlFq.js";import"./SaveButton-DsEf6QX8.js";import"./ExclamationCircleOutlined-GyY2ekzN.js";import"./CrudView-aCwhDtxY.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-D9ETPuvs.js";import"./constants-uJo_92lg.js";import"./url-DnDc1Az0.js";import"./PhDotsThreeVertical.vue-Rhd67F-F.js";import"./index-Aittn-tC.js";import"./asyncComputed-BmaNPgAU.js";import"./omniChatStore-Dbv9BTzt.js";import"./uuid-DD8YIIY0.js";import"./PhCopySimple.vue-Bzibpy3I.js";import"./PhPencil.vue-BAnbTwtw.js";import"./useCodebaseEvents-CyB5GF-M.js";import"./contracts.generated-B7B67kjj.js";import"./index-DTtpE0Cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="230ca48c-a644-4640-8542-45412115e5ee",o._sentryDebugIdIdentifier="sentry-dbid-230ca48c-a644-4640-8542-45412115e5ee")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,u)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-CpZcCY33.js.map
