import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DUzy3Too.js";import{A as h}from"./constants-uJo_92lg.js";import{a as v,c as y,ac as A,af as o,b as B,j as d,p as m,g as p,w as t,u as e,aj as I,b1 as f,B as N,S as a,U as l,h as x,b2 as C,ae as S,e as u,aN as T}from"./jwt-decode.esm-C3bBZEB2.js";import{u as D}from"./workspaceStore-Di3f8xeY.js";import{C as E}from"./index-Ga-NQaFo.js";import"./Logo-DNmBbXy6.js";import"./userStore-C8fkOSZz.js";import"./url-DnDc1Az0.js";import"./colorHelpers-57zbC7n6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new H().stack;c&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[c]="cac950a8-70bd-49d9-93cc-c8e82634a157",r._sentryDebugIdIdentifier="sentry-dbid-cac950a8-70bd-49d9-93cc-c8e82634a157")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},j=v({__name:"Error",setup(r){const c=A(),g=S(),_=D(),w=y(()=>_.state.workspace?.name??_.state.workspace?.brandName),n=y(()=>{const{status:i}=c.params;switch(i){case"404":return{status:i,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:i,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),b=()=>{g.push({name:"playerHome"})};return(i,s)=>(u(),B("div",R,[d(e(I),null,{default:t(()=>[a(l(n.value.title),1)]),_:1}),d(e(f),{class:"message"},{default:t(()=>[a(l(n.value.message),1)]),_:1}),n.value.action?(u(),m(e(N),{key:0,type:"link",onClick:b},{default:t(()=>[a(l(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(u(),m(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[x("div",V,[d(k,{style:{"margin-bottom":"10px"}}),d(e(f),null,{default:t(()=>[a("This page is part of "+l(w.value?`the ${w.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(_).state.workspace?(u(),m(e(f),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),d(e(C),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),H=T(j,[["__scopeId","data-v-522ad0d4"]]);export{H as default};
//# sourceMappingURL=Error-bLKb34ko.js.map
