import{C as a}from"./router-gFtZE6ii.js";import"./jwt-decode.esm-C3bBZEB2.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="a5e27ab5-a767-48d1-9464-af7c892b5919",r._sentryDebugIdIdentifier="sentry-dbid-a5e27ab5-a767-48d1-9464-af7c892b5919")}catch{}})();class i{async create(e){return a.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return a.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return a.get(`organizations/${e}/members`)}async get(e,n){return a.get(`organizations/${e}/members/${n}`)}async update(e,n,t){return a.patch(`organizations/${e}/members/${n}`,t)}}export{i as M};
//# sourceMappingURL=member-udbGr47z.js.map
