import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-a14BJ1AV.js";import{a as u,b as i,j as d,u as n,ae as m,ac as l,e as f,aN as _}from"./jwt-decode.esm-C3bBZEB2.js";import{u as b}from"./workspaceStore-Di3f8xeY.js";import"./OTPInput-BW5kuHsH.js";import"./Logo-DNmBbXy6.js";import"./string-DzKeI6fB.js";import"./CircularLoading-DDksgcKB.js";import"./index-DTtpE0Cf.js";import"./userStore-C8fkOSZz.js";import"./url-DnDc1Az0.js";import"./colorHelpers-57zbC7n6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ac1728b1-4ca0-4151-90df-45c722ea76e7",e._sentryDebugIdIdentifier="sentry-dbid-ac1728b1-4ca0-4151-90df-45c722ea76e7")}catch{}})();const g={class:"runner"},y=u({__name:"Login",setup(e){const o=m(),a=l(),r=b(),c=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(f(),i("div",g,[d(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),L=_(y,[["__scopeId","data-v-12c690e1"]]);export{L as default};
//# sourceMappingURL=Login-D24NZ9ig.js.map
