import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DUzy3Too.js";import{B as y}from"./BaseLayout-BpcxOCWt.js";import{a as l,P as _,a1 as b,aN as u,aG as v,aH as g,e as f,b as h,h as a,K as s,D as w,ae as S,p as k,w as n,ac as B,j as i,u as I}from"./jwt-decode.esm-C3bBZEB2.js";import{u as $}from"./editor-Bca7nItG.js";import{A as D}from"./index-ClGIvN-O.js";import"./Logo-DNmBbXy6.js";import"./router-CzoeTpaH.js";import"./workspaceStore-Di3f8xeY.js";import"./userStore-C8fkOSZz.js";import"./url-DnDc1Az0.js";import"./colorHelpers-57zbC7n6.js";import"./useCodebaseEvents-CyB5GF-M.js";import"./contracts.generated-B7B67kjj.js";import"./ts.worker-CPZkBJf0.js";import"./constants-uJo_92lg.js";import"./linters-BnWIG8uE.js";import"./asyncComputed-BmaNPgAU.js";import"./index-Aittn-tC.js";import"./index-Bb5v3hnM.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="381e7341-ea99-4279-b014-b9bc5f97ccc8",e._sentryDebugIdIdentifier="sentry-dbid-381e7341-ea99-4279-b014-b9bc5f97ccc8")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),P={class:"v-spinner"};function x(e,r,o,c,d,p){return v((f(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(L,[["render",x],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),c=$();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I(D),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[a("div",R,[i(K)])]),_:1}))}}),ee=u(j,[["__scopeId","data-v-d2a19803"]]);export{ee as default};
//# sourceMappingURL=ProjectLogin-CHH-Gc_U.js.map
