.content-layout[data-v-00e066e8]{overflow:auto;width:100%;height:100%;padding:20px 60px;box-sizing:border-box;display:flex;align-items:center;flex-direction:column}.content-layout.no-padding[data-v-00e066e8]{padding:0}.content-layout .centered-layout[data-v-00e066e8]{width:100%;height:100%;max-width:1024px}.content-layout .centered-layout.full-width[data-v-00e066e8]{max-width:unset}.content-layout .centered-layout.flex-layout[data-v-00e066e8]{display:flex;flex-direction:column;box-sizing:border-box}
