import{P as g}from"./PlayerNavbar-DxofMUGb.js";import{a as _,ac as c,r as h,c as y,b as k,p as v,g as w,h as b,u as n,j as L,a4 as C,ae as N,e as i,aN as I}from"./jwt-decode.esm-C3bBZEB2.js";import{u as V}from"./workspaceStore-Di3f8xeY.js";import"./userStore-C8fkOSZz.js";import"./metadata-CnU65AaU.js";import"./PhMagnifyingGlass.vue-B__USul3.js";import"./PhWebhooksLogo.vue-BX-R9Tg5.js";import"./LoadingOutlined-CF9FoGrU.js";import"./PhSignOut.vue-DJZmeMZV.js";import"./index-Bb5v3hnM.js";import"./url-DnDc1Az0.js";import"./colorHelpers-57zbC7n6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="a8edc517-0263-4314-9722-f4168c8621de",o._sentryDebugIdIdentifier="sentry-dbid-a8edc517-0263-4314-9722-f4168c8621de")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(o){const e=N(),t=V(),u=c().path,a=h(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=y(()=>!!c().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return i(),k("div",B,[n(t).state.workspace?(i(),v(g,{key:0,"current-path":n(u),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):w("",!0),b("section",D,[L(f)])])}}}),G=I(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-DxvOavck.js.map
