const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-D2_VCY5v.js","assets/workspaceStore-Di3f8xeY.js","assets/jwt-decode.esm-C3bBZEB2.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-C8fkOSZz.js","assets/url-DnDc1Az0.js","assets/colorHelpers-57zbC7n6.js","assets/OidcLogoutCallback-DfcvAykf.js","assets/Login-D24NZ9ig.js","assets/Login.vue_vue_type_script_setup_true_lang-a14BJ1AV.js","assets/OTPInput-BW5kuHsH.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-DNmBbXy6.js","assets/Logo-D2kepPyK.css","assets/string-DzKeI6fB.js","assets/CircularLoading-DDksgcKB.js","assets/CircularLoading-BiyobKo3.css","assets/index-DTtpE0Cf.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-DxvOavck.js","assets/PlayerNavbar-DxofMUGb.js","assets/metadata-CnU65AaU.js","assets/PhMagnifyingGlass.vue-B__USul3.js","assets/PhWebhooksLogo.vue-BX-R9Tg5.js","assets/LoadingOutlined-CF9FoGrU.js","assets/PhSignOut.vue-DJZmeMZV.js","assets/index-Bb5v3hnM.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-CLrHnzw4.js","assets/Watermark-CP0Cjc5C.js","assets/constants-uJo_92lg.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-_8ykP8nr.js","assets/index-Ga-NQaFo.js","assets/Home-B6UGln4L.css","assets/Error-bLKb34ko.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-DUzy3Too.js","assets/Error-CIbhyrKS.css","assets/Form-DWAynvTS.js","assets/FormRunner-3VldEjCn.js","assets/Steps-CCFr1jBb.js","assets/index-BleGAYYC.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-DajpE9Sy.js","assets/asyncComputed-BmaNPgAU.js","assets/uuid-DD8YIIY0.js","assets/Form-A1oa-Q46.css"])))=>i.map(i=>d[i]);
import{ag as s,ah as d,ad as t,ai as m}from"./jwt-decode.esm-C3bBZEB2.js";import{a as u}from"./workspaceStore-Di3f8xeY.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="779ad8c6-a09c-4e89-ad4b-25bc3411b6d1",e._sentryDebugIdIdentifier="sentry-dbid-779ad8c6-a09c-4e89-ad4b-25bc3411b6d1")}catch{}})();const f=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"bed601256811610f7c98632c295ef807a0b1028e"}catch(e){return console.error("Failed to fetch Abstra version:",e),"bed601256811610f7c98632c295ef807a0b1028e"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-D2_VCY5v.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-DfcvAykf.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-D24NZ9ig.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-DxvOavck.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-CLrHnzw4.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-bLKb34ko.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-DWAynvTS.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=s({history:d("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const n=await u(a.path),{redirect:i,...c}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...c,redirect:i||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router-CzoeTpaH.js.map
